@@ -13,12 +13,11 @@ class Course:
         self.name = name
 	self.term = term
 
-def isAllCaps(string){
-    for str in string:
-        if str.islower():
+def isAllCaps(string):
+    for letter in string:
+        if letter.islower():
            return False
     return True
-}
    
 def getCoursesTaken(html):
     parser = ParseCappReport()
@@ -33,4 +32,4 @@ def getCoursesTaken(html):
             term = html_text[i+4]
             courses.append(Course(name, term))
     return courses
-    
\ No newline at end of file
+    
